@@ -5,6 +5,6 @@ from .scoresaber_api import ScoreSaberAPI
 from .scoresaber_provider import ScoreSaberProvider
 from .errors import *
 from .models import *
+from .version import __version__
 
-handler = logging.StreamHandler()
-logging.getLogger("PyScoreSaber").addHandler(handler)
+logging.getLogger("pyscoresaber").addHandler(logging.NullHandler())
