@@ -3,6 +3,7 @@ from typing import List, Optional
 
 from dataclasses_json import dataclass_json
 
+from .badge import Badge
 from .fields import default
 from .score_stats import ScoreStats
 
@@ -12,18 +13,17 @@ from .score_stats import ScoreStats
 class Player:
     """Player data from ScoreSaber"""
 
-    player_id: str = default("playerId")
-    player_name: str = default("playerName")
-    avatar: str = default()
-    rank: int = default()
-    country_rank: int = default("countryRank")
-    pp: float = default()
+    id: str
+    name: str = default()
+    profile_picture: str = default("profilePicture")
     country: str = default()
-    role: str = default()
-    badges: List[str] = default()
-    history: str = default()
-    permissions: int = default()
-    inactive: int = default()
-    banned: int = default()
-
+    pp: float = default()
+    rank: int = default()
+    country_rank: Optional[int] = default("countryRank")
+    role: Optional[str] = default()
+    badges: Optional[List[Badge]] = default()
+    histories: str = default()
     score_stats: Optional[ScoreStats] = default("scoreStats")
+    permissions: Optional[int] = default()
+    banned: Optional[int] = default()
+    inactive: Optional[int] = default()
